@@ -9,8 +9,7 @@
 
 //関数
 
-require_once("../lib/require.php");
-require_once("../lib/pdo_search.php");
+require("../lib/pdo_search.php");
 	
 //本体
 
@@ -42,8 +41,8 @@ require_once("../lib/pdo_search.php");
 
 
 
+require("../lib/smarty.php");
 
-/*smarty*/
 if($flag == "true") {
 	$smarty->assign("book",$array[0]);
 	$smarty->assign("count",$count);
@@ -51,10 +50,7 @@ if($flag == "true") {
 }
 
 $smarty->assign("flag",$flag);
-
-$smarty_date = array("pagetitle" => "book_info");
 $smarty->assign("title","本の詳細"); //headerのtitle
-$smarty->assign("pagename","book_info");
 
 $smarty->display("book_info.tpl");
 
