@@ -9,8 +9,6 @@
 //関数
 require("../lib/pdo_search.php");
 require ("../lib/search_str.php");
-require_once("../lib/require.php");
-
 
 function getquery($name) {
 		$select = "SELECT * ";
@@ -74,7 +72,7 @@ if(isset($_GET['switch'] )) {
 }	
 
 
-/*smarty*/
+
 require("../lib/smarty.php");
 
 if($flag == "true") {
@@ -90,9 +88,7 @@ if(isset($name)) {
 }
 $smarty->assign("flag",$flag);
 $smarty->assign("title","本の検索"); //headerのtitle
-$smarty->assign("pagename","book_search");//pageの名前
-$smarty->assign("pagenumer",3); //何番目のページか
-$smarty->assign("totalpage",5);
+
 $smarty->display("book_search.tpl");
 
 
