@@ -1,10 +1,14 @@
 <?php
 include("../lib/session_on.php");
 
+$session = new session_on(); 
+
+if(isset($_POST['pass'])) {
+	$session->start();	
+}
 
 
 $book_array = array(title => "Fast CakePHP" ,limit => "12月31日");
-print_r($book_array);
 
 /*smarty*/
 
@@ -13,5 +17,6 @@ $smarty->assign("title","TOP"); //headerのtitle
 $smarty->assign("pagename","index");//pageの名前
 $smarty->assign("book_sum",$_COOKIE["TestCookie"]);
 $smarty->assign("book_date",$book_array);
+$smarty->assign("session_status",$session->getstatus("TestCookie"));
 $smarty->display("index.tpl");
 
