@@ -7,7 +7,7 @@
 		
 	$smarty->assign("title","TOP");
 	$smarty->assign("pagename","index");
-	//$smarty->assign("session_status",session_continue("TestCookie"));
-	$smarty->display("jstest.tpl");
+	$smarty->assign("session_status",session_continue("TestCookie"));
+	$smarty->display("index.tpl");
 
 	
