@@ -1,4 +1,4 @@
-<?php /* Smarty version 2.6.20, created on 2009-01-04 17:07:48
+<?php /* Smarty version 2.6.20, created on 2008-12-27 12:00:12
          compiled from borrow.tpl */ ?>
 <?php $_smarty_tpl_vars = $this->_tpl_vars;
 $this->_smarty_include(array('smarty_include_tpl_file' => "DTD.tpl", 'smarty_include_vars' => array()));
@@ -21,12 +21,15 @@ unset($_smarty_tpl_vars);
 		<div id="point">　<a href="index.php">TOP</a>&gt;検索結果&gt;詳細&gt;借り出し</div>
         <!--メイン画面-->
 	  <div id="main">
-	  <div id="borrow">
-	    <p>【貸出を確認致しました】</p>
-	    <p> 返却日　<?php echo $this->_tpl_vars['day']; ?>
+	  <div id="center">
+	    <p align="center">【借り出しを確認致しました】</p>
+	    <p align="center"> 返却日　<?php echo $this->_tpl_vars['day']; ?>
  </p>
-	    <p>必ず返却日にお返し下さい。</p>
-	  </div>	  </div>	</div> 	<div id="footer"></div>
+	    <p align="center">必ず返却日にお返し下さい。</p>
+	  </div>
+	  </div>
+	</div>
+	<div id="footer"></div>
 </div>
 <!--著作権表記-->
 <div id="cpyright">
