@@ -1,8 +1,8 @@
-<?php /* Smarty version 2.6.20, created on 2009-01-04 17:46:34
+<?php /* Smarty version 2.6.20, created on 2008-12-29 17:57:24
          compiled from header_index.tpl */ ?>
 <div id="header">
 <div id="header_login_index">
-<?php if ($_COOKIE['TestCookie'] == 3): ?>
+<?php if ($this->_tpl_vars['session_status'] == true): ?>
 
 	<ul>
 	<li><a href="userinfo.php">鈴木将之さんの情報</a></li>
