@@ -1,4 +1,4 @@
-<?php /* Smarty version 2.6.20, created on 2009-01-04 17:47:37
+<?php /* Smarty version 2.6.20, created on 2008-12-29 17:59:02
          compiled from header.tpl */ ?>
 <div id="header">
 
@@ -10,15 +10,14 @@
 		<span class="small_font"> 本のタイトルを入力してください </span>
 			<input  type="text" name="name"   value="" />
 	    	<label>
-	    	<input type="submit"  value="検索" />
+	    	<input type="submit" name="Submit" value="検索" />
 	    	<input type="hidden" name="switch" value="on" />
-		<input type="hidden" name="pagenumber" value="1" />
 		</label>
 		</p>
 		</form> 		
 	</div> <div id="header_login">
 
-<?php if ($_COOKIE['TestCookie'] == 3): ?>
+<?php if ($_COOKIE['TestCookie'] == true): ?>
 	<ul>
 	<li><a href="userinfo.php">鈴木将之さんの情報</a></li>
 	<li><a href="logout.php">ログアウト</a></li>
